@@ -49,6 +49,7 @@ int  sw;
     if(strcmp(yk+1, "there be") == 0){ strcpy(yk+7, "was"); return; }
     if(strcmp(yk+1, "there is") == 0){ strcpy(yk+7, "was"); return; }
     if(strcmp(yk+1, "there are") == 0){ strcpy(yk+7, "were"); return; }
+    if(strncmp(yk+1, "cannot ", 7) == 0){ ptreplace(yk+1, 3, "could "); return; }
     if(strncmp(yk+1, "is ", 3) == 0){ ptreplace(yk+1, 2, "was"); return; }
     if(strncmp(yk+1, "are ", 4) == 0){ ptreplace(yk+1, 3, "were"); return; }
     if(strncmp(yk+1, "has ", 4) == 0 || strcmp(yk+1, "has") == 0){ ptreplace(yk+1, 3, "have"); }
@@ -174,8 +175,10 @@ char *pt;
     if(strcmp(cmd, "&T") == 0){
   if(Dbg == 'Y') fprintf(dbg, "--- &T --- i = %d md = %s mz = %s \n", i, md[i], mz[i]);
       if(strchr(mz[i], 'K') && strchr(mz[i], 'h')) return;
+      if(strlen(md[i]+1) == 0) return; //16/10/21 P꒷=0
       if(strstr(md[i]+1, "wh") && !strstr(md[i]+1, "whi") && strncmp(md[i]+1, "wh", 2) != 0) return;
       if(strncmp(md[i]+1, "whether ", 8) == 0) return;
+      if(strncmp(md[i]+1, "how ", 4) == 0) return;
       if(strncmp(md[i]+1, "many ", 5) == 0) return;
       if(strncmp(md[i]+1, "only ", 5) == 0 || strncmp(md[i]+1, "nation", 6) == 0) goto JMP1; // the
       if(strchr(mz[i], 'y') ) goto JMP2;
@@ -515,7 +518,7 @@ char mdi[], mzi[], mdj[], mzj[];
 	//ؕ
         if(ispunct(*(mdi+1)) ||
          strncmp(mdi+1, "Japanese", 8) == 0 || strncmp(mdi+1, "%", 1) == 0
-	   || strncmp(mdi+1, "yen", 3) == 0 // || strncmp(mdi+1, "(", 1) == 0
+	   || strncmp(mdi+1, "yen", 3) == 0 || strncmp(mdi+1, "the ", 4) == 0
         || strncmp(mdi+1, "o'clock", 7) == 0) return;
 	// mdi+1̍ŏ̒Pplu猟v炻̕`Pɒu^[
 	if(irregPlu(mdi+1) == 1) return;
@@ -540,7 +543,7 @@ char mdi[], mzi[], mdj[], mzj[];
     }
     else{ //P
       if(strncmp(mdi+1, "the", 3) == 0 || strncmp(mdi+1, "someone", 7) == 0
-      || strncmp(mdi+1, "to ", 3) == 0
+	 || strncmp(mdi+1, "to ", 3) == 0 || strncmp(mdi+1, "how ",4) == 0
       || strncmp(mdi+1, "all", 3) == 0) return;
       if(strchr(mzi, 'K') || strstr(mdj+1, " and ") ) return;
 //  printf("--- ninsyo --- mdi = %s mzi = %s \n", mdi, mzi);
@@ -608,6 +611,9 @@ char *str, *ptone;
     }
 
     if(strncmp(ptone, "one's", 5) == 0) {
+      if(strcmp(str, "it") == 0){
+        ptreplace(ptone, 5, "its");    return;
+      }
       if(!strcmp(str, "I") || !strcmp(str, "me")){
         ptreplace(ptone, 5, "my");    return;
       }
